<?php
/* configuration constants */
define("MAIL_TO", "tickets@drum-klub.net");
define("MAIL_FROM", '"info@drum-klub.net" <info@drum-klub.net>');
define("MAIL_SUBJECT", "Online Ticket");

/* check if form post was submitted */
if (filter_has_var(INPUT_POST, "submit")) {
    $errors = NULL;

    /* check if all required variables are submitted */
    if (!filter_has_var(INPUT_POST, "name") ||
        !filter_has_var(INPUT_POST, "email") ||
        !filter_has_var(INPUT_POST, "show") ||
        !filter_has_var(INPUT_POST, "quantity"))
        $errors .= "<p class=\"error\">Please fill in the required fields!</p>\n";

    /* sanitize filters on post input */
    $filters = array(
        "name" => array("filter" => FILTER_SANITIZE_STRING, "flags" => FILTER_FLAG_STRIP_LOW),
        "email" => array("filter" => FILTER_SANITIZE_EMAIL),
        "show" => array("filter" => FILTER_SANITIZE_STRING, "flags" => FILTER_FLAG_STRIP_LOW),
        "quantity" => array("filter" => FILTER_SANITIZE_NUMBER_INT),
        "comment" => array("filter" => FILTER_SANITIZE_STRING, "flags" => FILTER_FLAG_STRIP_LOW),
    );
    $inputs = filter_input_array(INPUT_POST, $filters);

    /* validate variables after sanitizing */
    $int_opts = array("options"=>array("min_range"=>1, "max_range"=>20));
    if (empty($inputs["name"]) ||
        empty($inputs["show"]))
        $errors .= "<p class=\"error\">Please fill in all required fields!</p>\n";
    if (empty($inputs["email"]) || !filter_var($inputs["email"], FILTER_VALIDATE_EMAIL))
        $errors .= "<p class=\"error\">Please fill in a valid email address!</p>\n";
    if (empty($inputs["quantity"]) || !filter_var($inputs["quantity"], FILTER_VALIDATE_INT, $int_opts))
        $errors .= "<p class=\"error\">Please fill in a quantity in range 1 to 20.</p>\n";

    /* validate honeypot */
    if (!empty($inputs["website"]))
        $errors .= "<p class=\"error\">Please leave website empty!</p>\n";

    /* setup mail body and send mail if no errors */
    if (!$errors) {
        $mail_body="Online Ticket\n\n"
                  ."Name: ".$inputs["name"]."\n"
                  ."Email: ".$inputs["email"]."\n"
                  ."Show: ".$inputs["show"]."\n"
                  ."Quantity: ".$inputs["quantity"]."\n\n"
                  ."Comment:";
        if (!empty($inputs["comment"]))
                  $mail_body.="\n".$inputs["comment"];
        $mail_body.="\n\n";

        mail(MAIL_TO, MAIL_SUBJECT, $mail_body, "From: ". MAIL_FROM)
        or die("Error: Failed to send ticket email. Please contact us.");
    }
}
?>
<!DOCTYPE html>
<html>
    <head>
	<meta charset="utf-8">
	<meta content="Lars Neugebauer" name="author">
	<meta content="The drum klub is a movement to spread drumming, dancing, laughing and electronic music among a community." name="description">
	<meta content="Electronic music, Interactive drum (dance) performance, Druminstallationen, Incentive drumming, Berlin music performance, Electro, Insider tip Berlin music, Modern club atmosphere, Electro beats, Contemporary music-art, Drumlines" name="keywords">
	<title>drum klub</title>
	<link rel="stylesheet" type="text/css" href="style.css">
	<style type="text/css">body { background: url(images/tickets.jpg) no-repeat center center fixed; background-size: cover }</style>
    </head>
    <body>
	<span id="en"></span><span id="de"></span>
	<div id="fb-root"></div>
	<script>(function(d, s, id) {
	    var js, fjs = d.getElementsByTagName(s)[0];
	    if (d.getElementById(id)) return;
	    js = d.createElement(s); js.id = id;
	    js.src = "http://connect.facebook.net/en_US/all.js#xfbml=1";
	    fjs.parentNode.insertBefore(js, fjs);
	}(document, 'script', 'facebook-jssdk'));</script>
	<aside class="fade"><a href="index.html"><img src="images/logo.png" alt="drum klub" /></a></aside>
	<section class="fade">
	<nav lang="en">
	<div class="menu">
	    <a href="#en">Menu</a>
	    <ul>
		<li><a href="index.html#en">Home</a></li>
		<li><a href="about.html#en">About</a></li>
		<li><a href="media.html#en">Media</a></li>
		<!--<li><a href="tickets.php#en">Tickets</a></li>-->
		<li><a href="imprint.html#en">Imprint</a></li>
	    </ul>
	</div>
	<div class="minor">
	    <p>Tickets</p>
	    <p><a href="#en">en</a> <a href="#de">de</a> <a href="https://www.facebook.com/drumklub"><img src="images/fb.png" alt="facebook" /></a></p>
	    <p><div class="fb-like" data-action="like" data-colorscheme="dark" data-href="https://www.facebook.com/drumklub" data-layout="button_count" data-width="80"></div></p>
	    <p><em>get lucky and keep<br />drumming with dk</em></p>
	</div>
	</nav>
	<nav lang="de">
	<div class="menu">
	    <a href="#de">Menu</a>
	    <ul>
		<li><a href="index.html#de">Home</a></li>
		<li><a href="about.html#de">About</a></li>
		<li><a href="media.html#de">Media</a></li>
		<!--<li><a href="tickets.php#de">Tickets</a></li>-->
		<li><a href="imprint.html#de">Imprint</a></li>
	    </ul>
	</div>
	<div class="minor">
	    <p>Tickets</p>
	    <p><a href="#en">en</a> <a href="#de">de</a> <a href="https://www.facebook.com/drumklub"><img src="images/fb.png" alt="facebook" /></a></p>
	    <p><div class="fb-like" data-action="like" data-colorscheme="dark" data-href="https://www.facebook.com/drumklub" data-layout="button_count" data-width="80"></div></p>
	    <p><em>get lucky and keep<br />drumming with dk</em></p>
	</div>
	</nav>
	<article lang="en">
	<p>Grab tickets as long as you can!<br />If you have any questions: <a href="mailto:info@drum-klub.net">info@drum-klub.net</a></p>
	<p>Go directly to advance ticket sales:<br /><a href="https://www.eventbrite.de/o/drum-klub-18611976186" target="_blank">Berlin</a> or <a href="https://waschhauspotsdam.reservix.de/p/reservix/group/158181" target="_blank">Potsdam</a></p>
	<h1>Tickets</h1>
	</article>
	<article lang="de">
	<p>Schnappt sie euch, solange ihr noch k&ouml;nnt!<br />Bei Fragen: <a href="mailto:info@drum-klub.net">info@drum-klub.net</a></p>
	<p>Direkt zum Kartenvorverkauf:<br /><a href="https://www.eventbrite.de/o/drum-klub-18611976186" target="_blank">Berlin</a> oder <a href="https://waschhauspotsdam.reservix.de/p/reservix/group/158181" target="_blank">Potsdam</a></p>
	<h1>Tickets</h1>
	</article>
	<article>
	<?php if (filter_has_var(INPUT_POST, "submit") && !$errors) { ?>
	<p>Thanks for your request! We will send you a confirmation email as soon as possible.</p>
	<?php } else { ?>
        <form action="<?php print $_SERVER['PHP_SELF']; ?>" method="post">
	    <fieldset>
		<!--<legend>Ticket Form</legend>-->
        	<?php if (isset($errors)) echo $errors; ?>
		<p><label for="name">Name</label>
		<input id="name" name="name" size="50" type="text" placeholder="John Doe" value="<?php echo(isset($_POST['submit']) ? $_POST['name'] : ''); ?>" required /></p>
		<p><label for="email">Email</label>
		<input id="email" name="email" size="50" type="email" placeholder="mail@example.com" value="<?php echo(isset($_POST['submit']) ? $_POST['email'] : ''); ?>" required /></p>
		<p id="hp"><label for="website">Leave empty</label>
		<input id="website" name="website" size="128" type="url" placeholder="http://www.example.com" /></p>
		<p><label for="show">Show</label>
		<select id="show" name="show" required>
                        <option selected>Wed 03.04.2024 Potsdam Waschhaus</option>
		</select></p>
		<p><label for="quantity">Quantity</label>
		<input id="quantity" name="quantity" size="50" type="number" max="20" min="1" step="1" value="<?php echo(isset($_POST['submit']) ? $_POST['quantity'] : '2'); ?>" required /></p>
		<p><label for="comment">Comment</label>
		<textarea id="comment" name="comment" size="250" placeholder="Write something to us&hellip;"><?php echo(isset($_POST['submit']) ? $_POST['comment'] : ''); ?></textarea></p>
		<p><button id="submit" name="submit" type="submit" value="submit">Send</button></p>
	    </fieldset>
	</form>
	<?php } ?>
	</article>
	</section>
    </body>
</html>
